{{ cookiecutter.project_name }}
{{ "=" * cookiecutter.project_name|length }}

{{ cookiecutter.short_description }}


Table of Contents
-----------------

.. toctree::
   :maxdepth: 2

   tutorials/index
   howto/index
   concepts/index
   reference/index
